@@ -1,10 +1,11 @@
 from dynts.utils import import_module
 from dynts.conf import settings
-from base import TimeSeries, Formatters, xydata, DynData, ops, ts_bin_op
+
+from .xy import *
+from .base import TimeSeries, ops, ts_bin_op
 
 BACKENDS = {
     'zoo': 'zoo',
-    'rmetrics': 'rmetrics',
     'numpy': 'tsnumpy',
 }
 
