@@ -16,8 +16,8 @@ class Expr(object):
         '''Number of nodes'''
         return 1
     
-    def __unicode__(self):
-        return u'%s' % self.info()
+    def malformed(self):
+        return False
     
     @property
     def type(self):
@@ -46,7 +46,8 @@ class Expr(object):
         return None
     
     def unwind(self, values, backend, **kwargs):
-        '''Unwind expression by applying *values* to the abstract nodes'''
+        '''Unwind expression by applying *values* to the abstract nodes.
+the ``kwargs`` dictionary can contain data which can be used to override values'''
         if not hasattr(self, "_unwind_value"):
             self._unwind_value = self._unwind(values, backend, **kwargs)
         return self._unwind_value
@@ -64,6 +65,13 @@ class BaseExpression(Expr):
     def info(self):
         return str(self.value)
         
+
+class BadExpression(BaseExpression):
+    '''A malformed expression
+    '''
+    def malformed(self):
+        return True
+    
     
 class Expression(BaseExpression):
     '''Base class for single expression
@@ -123,13 +131,24 @@ class Symbol(BaseExpression):
     '''
     def __init__(self, value, field = None):
         value = settings.symboltransform(value)
-        super(Symbol,self).__init__(value)
+        if len(value)>2 and value[0] == '`' and value[-1] == '`':
+            self.quotes = True
+            value = value[1:-1]
+        else:
+            self.quotes = False
+        super(Symbol,self).__init__(str(value))
     
+    def info(self):
+        if self.quotes:
+            return '`{0}`'.format(self.value)
+        else:
+            return self.value
+        
     def symbols(self):
-        return [str(self)]
+        return [self.value]
     
     def _unwind(self, values, backend, **kwargs):
-        sdata = values[str(self)]
+        sdata = values[self.value]
         if istimeseries(sdata):
             return sdata
         else:
@@ -137,7 +156,11 @@ class Symbol(BaseExpression):
                             date = sdata['date'],
                             data = sdata['value'],
                             backend = backend)
-            values[ts.name] = ts
+            # Uses this hack to make sure timeseries are ordered
+            # Lots of room for performance improvement
+            hash = ts.ashash()
+            hash.modified = True
+            values[ts.name] = hash.getts()
             return ts
     
     def lineardecomp(self):
@@ -152,6 +175,12 @@ class MultiExpression(Expr):
         self.children        = []
         self.concat_operator = concat_operator
         
+    def malformed(self):
+        for child in self.children:
+            if child.malformed():
+                return True
+        return False
+    
     def __len__(self):
         return len(self.children)
     
@@ -231,7 +260,7 @@ class ConcatenationOp(ConcatOp):
     def _unwind(self, values, backend, sametype = True, **kwargs):
         result = []
         for child in self:
-            result.append(child.unwind(values, backend))
+            result.append(child.unwind(values, backend, **kwargs))
         return result
     
     
@@ -283,8 +312,11 @@ The left hand side is **never** a symbol.
         super(EqualOp,self).__init__(left,right,"=")
         
     def _unwind(self, values, backend, **kwargs):
-        data = self.right.unwind(values, backend, **kwargs)
-        return {str(self.left):data}
+        name = str(self.left)
+        if name in kwargs:
+            return {name:kwargs[name]}
+        else:
+            return {name:self.right.unwind(values, backend, **kwargs)}
  
  
 class Bracket(Expression):
