@@ -1,12 +1,12 @@
-from django.conf import settings
-from django import forms
-from django.template import loader
-
-from djpcms.utils import mark_safe
+'''Web plugins for djpcms
+https://github.com/lsbardel/djpcms
+'''
+from djpcms import sites, forms
+from djpcms.template import loader
 from djpcms.plugins import DJPplugin
 from djpcms.views import appsite
 
-skin = getattr(settings,'DYNTS_SKIN','dynts/ecoplot/skins/smooth.css')
+skin = getattr(sites.settings,'DYNTS_SKIN','dynts/ecoplot/skins/smooth.css')
 
 
 class EcoForm(forms.Form):
@@ -14,6 +14,7 @@ class EcoForm(forms.Form):
     default_show = forms.BooleanField(initial = True, required = False)
     height = forms.IntegerField()
     
+    
 class EcoPlot(DJPplugin):
     '''Plugin for djpcms__ content management system.
 
@@ -29,15 +30,18 @@ __ http://packages.python.org/djpcms/'''
         js = ['dynts/flot/excanvas.min.js',
               'dynts/flot/jquery.flot.min.js',
               'dynts/flot/jquery.flot.selection.min.js',
+              'dynts/jquery.flot.text.js',
               'dynts/ecoplot/ecoplot.js',
               'dynts/decorator.js']
     
-    def render(self, djp, wrapper, prefix, height = 400, default_show = True, url = '', **kwargs):
+    def render(self, djp, wrapper, prefix, height = 400,
+               default_show = True, url = '', start = None, **kwargs):
         height = abs(int(height))
         ctx = {'url':    url,
                'height': height,
                'default_show': default_show,
-               'item':   djp.instancecode()}
+               'item':   djp.instancecode(),
+               'start': start}
         return loader.render_to_string('dynts/econometric-plot.html', ctx)
     
 
